/* GNOME DB libary
 * Copyright (C) 1998 Michael Lausch
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __GDA_COMMAND_H__
#define __GDA_COMMAND_H__

#include "gda-types.h"


Gda_ODBC_Command*      gda_odbc_cmd_new                (void);
void                   gda_odbc_cmd_free               (Gda_ODBC_Command* cmd);
     
Gda_ODBC_Connection*   gda_odbc_cmd_set_connection     (Gda_ODBC_Command* cmd, Gda_ODBC_Connection* cnc);
Gda_ODBC_Recordset*    gda_odbc_cmd_execute            (Gda_ODBC_Command* cmd,
							const GDA_CmdParameterSeq* params,
							gulong* affected_rows,
							gulong options);
#endif

